"""Type definitions for PyBuildingCluster."""

from typing import Dict, List, Any, Optional
import pandas as pd

ClusterResults = Dict[str, Any]
ModelResults = Dict[str, Any] 
SensitivityResults = Dict[str, Any]
ScenarioDefinition = Dict[str, Any]